@@ -4,7 +4,7 @@
  * GChemPaint library
  * atom.h 
  *
- * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -34,12 +34,12 @@
 #include <gcu/element.h>
 #include <gcu/macros.h>
 
-namespace OpenBabel
-{
-	class OBAtom;
+/*!\file*/
+
+namespace gcu {
+class UIManager;
 }
 
-/*!\file*/
 namespace gcp {
 
 class Bond;
@@ -127,13 +127,6 @@ Default construtor.
 */
 	Atom (int Z, double x, double y, double z);
 /*!
-@param atom an OpenBabel Atom instance.
-
-Builds an atom importing as many properties from an existing OpenBabel
-Atom instance.
-*/
-	Atom (OpenBabel::OBAtom* atom);
-/*!
 The destructor.
 */
 	virtual ~Atom ();
@@ -266,6 +259,14 @@ the maximum valence for the element.
 */
 	virtual double GetYAlign ();
 /*!
+@param x the x component of the transation vector.
+@param y the y component of the transation vector.
+@param z the z component of the transation vector.
+
+Used to move an Atom.
+*/
+	virtual void Move (double x, double y, double z = 0.);
+/*!
 @param m the Matrix2D of the transformation.
 @param x the x component of the center of the transformation.
 @param y the y component of the center of the transformation.
@@ -274,14 +275,14 @@ Used to move and/or transform an object.
 */
 	virtual void Transform2D (gcu::Matrix2D& m, double x, double y);
 /*!
-@param UIManager: the GtkUIManager to populate.
+@param UIManager: the gcu::UIManager to populate.
 @param object the atom on which occured the mouse click.
 @param x x coordinate of the mouse click.
 @param y y coordinate of the mouse click.
 
 This method is called to build a contextual menu for the atom.
 */
-	bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
+	bool BuildContextualMenu (gcu::UIManager *UIManager, Object *object, double x, double y);
 /*!
 @param Mol: a pointer to a molecule
 
@@ -384,6 +385,9 @@ This method is used to avoid bonds lines extyending over their atoms symbols.
 */
 	Bond *GetBondAtAngle (double angle);
 
+	bool UpdateStereoBonds ();
+	bool HasStereoBond () const;
+
 protected:
 /*!
 @param width the witdh of the atomic symbol.
@@ -394,6 +398,15 @@ Evaluates where lines representing bonds should end to not overload the symbol.
 */
 	void BuildSymbolGeometry (double width, double height, double ascent);
 
+/*!
+@param property the identity of the property as defined in objprops.h.
+@param value the value of the property as a string.
+
+Used by the gcu::Loader mechanism to load properties of atoms.
+@return true on success.
+*/
+	bool SetProperty (unsigned property, char const *value);
+
 private:
 	void UpdateAvailablePositions ();
 
@@ -430,6 +443,9 @@ private:
 	// special offset for underlying rectangle; will be removed in next version
 	double m_xROffs, m_yROffs;
 
+	// atom parity stuff
+	Atom *m_Bonded[4]; // always using positive parity
+
 protected:
 /*!
 Half the height of the "C" character.
