@@ -4,7 +4,7 @@
  * GChemPaint residues plugin
  * residues-dlg.cc
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -109,7 +109,12 @@ static int insert_symbol (GtkComboBox *box, char const *str)
 	GtkTreeIter iter;
 	int i = 1;
 	if (!gtk_tree_model_get_iter_from_string (model, &iter, "1")) {
+#if GTK_CHECK_VERSION (2, 24, 0)
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, str, -1);
+#else
 		gtk_combo_box_append_text (box, str);
+#endif
 		return i;
 	}
 	char* text;
@@ -118,12 +123,22 @@ static int insert_symbol (GtkComboBox *box, char const *str)
 		if (gtk_tree_model_iter_next (model, &iter))
 			gtk_tree_model_get (model, &iter, 0, &text, -1);
 		else {
+#if GTK_CHECK_VERSION (2, 24, 0)
+			gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, str, -1);
+#else
 			gtk_combo_box_append_text (box, str);
+#endif
 			return i + 1;
 		}
 		i++;
 	}
+#if GTK_CHECK_VERSION (2, 24, 0)
+		gtk_list_store_insert (GTK_LIST_STORE (model), &iter, i);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, str, -1);
+#else
 	gtk_combo_box_insert_text (box, i, str);
+#endif
 	return i;
 }
 
@@ -131,7 +146,9 @@ static void delete_symbol (GtkComboBox *box, char const *str)
 {
 	GtkTreeModel *model = gtk_combo_box_get_model (box);
 	GtkTreeIter iter;
+#if !GTK_CHECK_VERSION (2, 24, 0)
 	int i = 1;
+#endif
 	if (!gtk_tree_model_get_iter_from_string (model, &iter, "1"))
 		return;
 	char* text;
@@ -141,13 +158,19 @@ static void delete_symbol (GtkComboBox *box, char const *str)
 			gtk_tree_model_get (model, &iter, 0, &text, -1);
 		else
 			return;
+#if !GTK_CHECK_VERSION (2, 24, 0)
 		i++;
+#endif
 	}
+#if GTK_CHECK_VERSION (2, 24, 0)
+	gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+#else
 	gtk_combo_box_remove_text (box, i);
+#endif
 }
 
 gcpResiduesDlg::gcpResiduesDlg (gcp::Application *App):
-	Dialog (App, UIDIR"/residues.ui", "residues", GETTEXT_PACKAGE, App),
+	gcugtk::Dialog (App, UIDIR"/residues.ui", "residues", GETTEXT_PACKAGE, App),
 	gcp::Target (App)
 {
 	m_Document = new gcp::Document (App, true, NULL);
@@ -179,8 +202,17 @@ gcpResiduesDlg::gcpResiduesDlg (gcp::Application *App):
 	m_CurBox = GTK_COMBO_BOX (GetWidget ("cur-box"));
 	ResidueIterator i;
 	string const *s = Residue::GetFirstResidueSymbol (i);
+#if GTK_CHECK_VERSION (2, 24, 0)
+	GtkListStore *list = GTK_LIST_STORE (gtk_combo_box_get_model (m_CurBox));
+	GtkTreeIter iter;
+#endif
 	while (s) {
+#if GTK_CHECK_VERSION (2, 24, 0)
+		gtk_list_store_append (list, &iter);
+		gtk_list_store_set (list, &iter, 0, s->c_str (), -1);
+#else
 		gtk_combo_box_append_text (m_CurBox, s->c_str ());
+#endif
 		s = Residue::GetNextResidueSymbol (i);
 	}
 	gtk_combo_box_set_active (m_CurBox, 0);
@@ -398,7 +430,17 @@ bool gcpResiduesDlg::OnKeyRelease (GdkEventKey *event)
 
 void gcpResiduesDlg::OnCurChanged ()
 {
+#if GTK_CHECK_VERSION (2, 24, 0)
+	char *symbol;
+	GtkTreeIter iter;
+	GtkTreePath *path = gtk_tree_path_new_from_indices (gtk_combo_box_get_active (m_CurBox), -1);
+	GtkTreeModel *model = gtk_combo_box_get_model (m_CurBox);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_path_free (path);
+	gtk_tree_model_get (model, &iter, 0, &symbol, -1);
+#else
 	char *symbol = gtk_combo_box_get_active_text (m_CurBox);
+#endif
 	if (!strcmp (symbol, _("New"))) {
 		m_Residue = NULL;
 		gtk_entry_set_text (m_NameEntry, "");
@@ -409,6 +451,7 @@ void gcpResiduesDlg::OnCurChanged ()
 		gtk_widget_set_sensitive (m_DeleteBtn, false);
 		gtk_widget_set_sensitive (m_GenericBtn, true);
 		m_Document->SetEditable (true);
+		g_free (symbol);
 		return;
 	}
 	m_Residue = const_cast <gcp::Residue *> (static_cast<gcp::Residue const*> (Residue::GetResidue (symbol)));
@@ -452,6 +495,7 @@ void gcpResiduesDlg::OnCurChanged ()
 	static_cast <gcp::Atom *>((*j).first)->Lock ();
 	static_cast <gcp::Bond *>((*j).second)->Lock ();
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (m_GenericBtn), m_Residue->GetGeneric ());
+	g_free (symbol);
 }
 
 void gcpResiduesDlg::OnSymbolActivate ()
@@ -475,8 +519,17 @@ void gcpResiduesDlg::OnNewResidue (gcp::Residue *res)
 	if (res) {
 		map<string, bool> const &symbols = res->GetSymbols ();
 		map<string, bool>::const_iterator i = symbols.begin (), end = symbols.end ();
+#if GTK_CHECK_VERSION (2, 24, 0)
+		GtkListStore *list = GTK_LIST_STORE (gtk_combo_box_get_model (m_CurBox));
+		GtkTreeIter iter;
+		for (i = symbols.begin (); i != end; i++) {
+			gtk_list_store_append (list, &iter);
+			gtk_list_store_set (list, &iter, 0, (*i).first.c_str (), -1);
+		}
+#else
 		for (i = symbols.begin (); i != end; i++)
 			gtk_combo_box_append_text (m_CurBox, (*i).first.c_str ());
+#endif
 	} else if (m_Residue && !m_Residue->GetReadOnly ())
 		gtk_widget_set_sensitive (m_DeleteBtn, m_Residue->GetRefs () == 0);
 }
