@@ -4,7 +4,7 @@
  * Gnome Crystal
  * prefs.h 
  *
- * Copyright (C) 2001-2006 Jean Brfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Brfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -18,20 +18,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
 #ifndef GCRYSTAL_PREFS_H
 #define GCRYSTAL_PREFS_H
 
-#include <gcu/dialog.h>
+#include <gcugtk/dialog.h>
 
 using namespace gcu;
 
 class gcApplication;
 
-class gcPrefsDlg: public Dialog
+class gcPrefsDlg: public gcugtk::Dialog
 {
 public:
 	gcPrefsDlg (gcApplication *App);
