@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/spectra/document.cc
  *
- * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2011Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -32,7 +32,7 @@
 using namespace gcu;
 using namespace std;
 
-gsvDocument::gsvDocument (gsvApplication *App): SpectrumDocument (App, new gsvView (this))
+gsvDocument::gsvDocument (gsvApplication *App): gcugtk::SpectrumDocument (App, new gsvView (this))
 {
 }
 
@@ -40,17 +40,10 @@ gsvDocument::~gsvDocument ()
 {
 }
 
-void gsvDocument::Load (char const *uri, char const *mime_type)
+void gsvDocument::SetTitle (char const *title)
 {
-	SpectrumDocument::Load (uri, mime_type);
-	string title = GetTitle ();
-	if (title.length () == 0) {
-		title = g_path_get_basename (uri);
-		char *buf = g_uri_unescape_string (title.c_str (), NULL);
-		title = buf;
-		g_free (buf);
-	}
-	dynamic_cast <gsvView *> (m_View)->GetWindow ()->SetTitle (title);
-	string dirname = g_path_get_dirname (uri);
-	m_App->SetCurDir (dirname);
+	gcugtk::SpectrumDocument::SetTitle (title);
+	gsvView *view = dynamic_cast <gsvView *> (m_View);
+	if (view && view->GetWindow ())
+		view->GetWindow ()->SetTitle (title);
 }
