@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/spectra/window.cc
  *
- * Copyright (C) 2007-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,7 +27,7 @@
 #include "document.h"
 #include "view.h"
 #include "window.h"
-#include <gcu/print-setup-dlg.h>
+#include <gcugtk/print-setup-dlg.h>
 #include <gsf/gsf-output-memory.h>
 #include <glib/gi18n.h>
 
@@ -106,12 +106,7 @@ static void on_bug (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
 	window->GetApp ()->OnBug ();
 }
 
-static void on_about_activate_url (G_GNUC_UNUSED GtkAboutDialog *about, const gchar *url, gpointer data)
-{
-	reinterpret_cast <gsvWindow *> (data)->GetApp ()->OnWeb (url);
-}
-
-static void on_about (G_GNUC_UNUSED GtkWidget *widget, gsvWindow *Win)
+static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gsvWindow *Win)
 {
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GSpectrum is a spectrum viewer for Gnome");
@@ -130,8 +125,6 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gsvWindow *Win)
 		"along with this program; if not, write to the Free Software\n"
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1307\n"
 		"USA";
-	
-	gtk_about_dialog_set_url_hook (on_about_activate_url, Win, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
@@ -171,7 +164,10 @@ static bool on_motion (GOGraphWidget *widget, GdkEventMotion *event, G_GNUC_UNUS
 	x_axis = GOG_AXIS (l->data);
 	g_slist_free (l);
 	l = gog_chart_get_axes (chart, GOG_AXIS_Y);
-	y_axis = GOG_AXIS (l->data);
+	// we need to use the first y axis, which comes last in the list, is this a kludge?
+	GSList *ptr;
+	for (ptr = l; ptr && ptr->next; ptr = ptr->next);
+	y_axis = GOG_AXIS (ptr->data);
 	g_slist_free (l);
     GogChartMap *map = gog_chart_map_new (chart,
             &(view->allocation), x_axis, y_axis, NULL, FALSE);
@@ -282,7 +278,10 @@ gsvWindow::gsvWindow (gsvApplication *App, gsvDocument *Doc)
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
 	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
-	gtk_recent_filter_add_mime_type (filter, "chemical/x-jcamp-dx");
+	std::list<std::string> &mime_types = App->GetSupportedMimeTypes ();
+	std::list<std::string>::iterator it, end = mime_types.end ();
+	for (it = mime_types.begin (); it != end; it++)
+		gtk_recent_filter_add_mime_type (filter, (*it).c_str ());
 	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (w), filter);
 	g_signal_connect (G_OBJECT (w), "item-activated", G_CALLBACK (on_recent), this);
 	GtkWidget *item = gtk_menu_item_new_with_label (_("Open recent"));
@@ -320,7 +319,7 @@ void gsvWindow::OnFileClose ()
 
 void gsvWindow::OnPageSetup ()
 {
-	new gcu::PrintSetupDlg (m_App, m_Doc);
+	new gcugtk::PrintSetupDlg (m_App, m_Doc);
 }
 
 static GtkTargetEntry const targets[] = {
